--- This file has been generated by scripts/build_db.py. DO NOT EDIT !

INSERT INTO "geodetic_crs" VALUES('EPSG','3819','HD1909',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1024','EPSG','1119',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','3821','TWD67',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1025','EPSG','3315',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','3822','TWD97',NULL,NULL,'geocentric','EPSG','6500','EPSG','1026','EPSG','1228',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','3823','TWD97',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1026','EPSG','1228',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','3824','TWD97',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1026','EPSG','1228',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','3887','IGRS',NULL,NULL,'geocentric','EPSG','6500','EPSG','1029','EPSG','1124',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','3888','IGRS',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1029','EPSG','1124',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','3889','IGRS',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1029','EPSG','1124',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','3906','MGI 1901',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1031','EPSG','2370',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4000','MOLDREF99',NULL,NULL,'geocentric','EPSG','6500','EPSG','1032','EPSG','1162',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4001','Unknown datum based upon the Airy 1830 ellipsoid',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6001','EPSG','1263',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4002','Unknown datum based upon the Airy Modified 1849 ellipsoid',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6002','EPSG','1263',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4003','Unknown datum based upon the Australian National Spheroid',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6003','EPSG','1263',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4004','Unknown datum based upon the Bessel 1841 ellipsoid',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6004','EPSG','1263',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4005','Unknown datum based upon the Bessel Modified ellipsoid',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6005','EPSG','1263',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4006','Unknown datum based upon the Bessel Namibia ellipsoid',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6006','EPSG','1263',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4007','Unknown datum based upon the Clarke 1858 ellipsoid',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6007','EPSG','1263',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4008','Unknown datum based upon the Clarke 1866 ellipsoid',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6008','EPSG','1263',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4009','Unknown datum based upon the Clarke 1866 Michigan ellipsoid',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6009','EPSG','1263',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4010','Unknown datum based upon the Clarke 1880 (Benoit) ellipsoid',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6010','EPSG','1263',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4011','Unknown datum based upon the Clarke 1880 (IGN) ellipsoid',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6011','EPSG','1263',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4012','Unknown datum based upon the Clarke 1880 (RGS) ellipsoid',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6012','EPSG','1263',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4013','Unknown datum based upon the Clarke 1880 (Arc) ellipsoid',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6013','EPSG','1263',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4014','Unknown datum based upon the Clarke 1880 (SGA 1922) ellipsoid',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6014','EPSG','1263',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4015','Unknown datum based upon the Everest 1830 (1937 Adjustment) ellipsoid',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6015','EPSG','1263',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4016','Unknown datum based upon the Everest 1830 (1967 Definition) ellipsoid',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6016','EPSG','1263',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4017','MOLDREF99',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1032','EPSG','1162',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4018','Unknown datum based upon the Everest 1830 Modified ellipsoid',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6018','EPSG','1263',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4019','Unknown datum based upon the GRS 1980 ellipsoid',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6019','EPSG','1263',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4020','Unknown datum based upon the Helmert 1906 ellipsoid',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6020','EPSG','1263',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4021','Unknown datum based upon the Indonesian National Spheroid',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6021','EPSG','1263',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4022','Unknown datum based upon the International 1924 ellipsoid',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6022','EPSG','1263',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4023','MOLDREF99',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1032','EPSG','1162',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4024','Unknown datum based upon the Krassowsky 1940 ellipsoid',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6024','EPSG','1263',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4025','Unknown datum based upon the NWL 9D ellipsoid',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6025','EPSG','1263',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4027','Unknown datum based upon the Plessis 1817 ellipsoid',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6027','EPSG','1263',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4028','Unknown datum based upon the Struve 1860 ellipsoid',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6028','EPSG','1263',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4029','Unknown datum based upon the War Office ellipsoid',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6029','EPSG','1263',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4030','Unknown datum based upon the WGS 84 ellipsoid',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6030','EPSG','1263',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4031','Unknown datum based upon the GEM 10C ellipsoid',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6031','EPSG','1263',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4032','Unknown datum based upon the OSU86F ellipsoid',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6032','EPSG','1263',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4033','Unknown datum based upon the OSU91A ellipsoid',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6033','EPSG','1263',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4034','Unknown datum based upon the Clarke 1880 ellipsoid',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6034','EPSG','1263',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4035','Unknown datum based upon the Authalic Sphere',NULL,NULL,'geographic 2D','EPSG','6402','EPSG','6035','EPSG','1263',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4036','Unknown datum based upon the GRS 1967 ellipsoid',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6036','EPSG','1263',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4039','RGRDC 2005',NULL,NULL,'geocentric','EPSG','6500','EPSG','1033','EPSG','3613',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4040','RGRDC 2005',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1033','EPSG','3613',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4041','Unknown datum based upon the Average Terrestrial System 1977 ellipsoid',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6041','EPSG','1263',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4042','Unknown datum based upon the Everest (1830 Definition) ellipsoid',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6042','EPSG','1263',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4043','Unknown datum based upon the WGS 72 ellipsoid',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6043','EPSG','1263',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4044','Unknown datum based upon the Everest 1830 (1962 Definition) ellipsoid',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6044','EPSG','1263',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4045','Unknown datum based upon the Everest 1830 (1975 Definition) ellipsoid',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6045','EPSG','1263',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4046','RGRDC 2005',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1033','EPSG','3613',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4047','Unspecified datum based upon the GRS 1980 Authalic Sphere',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6047','EPSG','1263',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4052','Unspecified datum based upon the Clarke 1866 Authalic Sphere',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6052','EPSG','1263',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4053','Unspecified datum based upon the International 1924 Authalic Sphere',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6053','EPSG','1263',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4054','Unspecified datum based upon the Hughes 1980 ellipsoid',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6054','EPSG','1263',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4055','Popular Visualisation CRS',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6055','EPSG','1262',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4073','SREF98',NULL,NULL,'geocentric','EPSG','6500','EPSG','1034','EPSG','4543',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4074','SREF98',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1034','EPSG','4543',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4075','SREF98',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1034','EPSG','4543',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4079','REGCAN95',NULL,NULL,'geocentric','EPSG','6500','EPSG','1035','EPSG','3199',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4080','REGCAN95',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1035','EPSG','3199',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4081','REGCAN95',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1035','EPSG','3199',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4120','Greek',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6120','EPSG','3254',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4121','GGRS87',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6121','EPSG','3254',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4122','ATS77',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6122','EPSG','1283',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4123','KKJ',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6123','EPSG','3333',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4124','RT90',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6124','EPSG','1225',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4125','Samboja',NULL,NULL,'geographic 2D','EPSG','6402','EPSG','6125','EPSG','1328',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4126','LKS94 (ETRS89)',NULL,NULL,'geographic 2D','EPSG','6402','EPSG','6126','EPSG','1145',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4127','Tete',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6127','EPSG','3281',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4128','Madzansua',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6128','EPSG','1315',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4129','Observatario',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6129','EPSG','1329',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4130','Moznet',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6130','EPSG','1167',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4131','Indian 1960',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6131','EPSG','4007',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4132','FD58',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6132','EPSG','1300',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4133','EST92',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6133','EPSG','3246',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4134','PSD93',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6134','EPSG','3288',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4135','Old Hawaiian',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6135','EPSG','1334',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4136','St. Lawrence Island',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6136','EPSG','1332',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4137','St. Paul Island',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6137','EPSG','1333',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4138','St. George Island',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6138','EPSG','1331',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4139','Puerto Rico',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6139','EPSG','1335',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4140','NAD83(CSRS98)',NULL,NULL,'geographic 2D','EPSG','6402','EPSG','6140','EPSG','1336',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4141','Israel 1993',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6141','EPSG','2603',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4142','Locodjo 1965',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6142','EPSG','1075',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4143','Abidjan 1987',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6143','EPSG','1075',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4144','Kalianpur 1937',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6144','EPSG','1308',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4145','Kalianpur 1962',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6145','EPSG','1184',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4146','Kalianpur 1975',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6146','EPSG','3341',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4147','Hanoi 1972',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6147','EPSG','3328',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4148','Hartebeesthoek94',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6148','EPSG','4540',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4149','CH1903',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6149','EPSG','1286',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4150','CH1903+',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6150','EPSG','1286',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4151','CHTRF95',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6151','EPSG','1286',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4152','NAD83(HARN)',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6152','EPSG','1337',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4153','Rassadiran',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6153','EPSG','1338',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4154','ED50(ED77)',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6154','EPSG','1123',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4155','Dabola 1981',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6155','EPSG','3257',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4156','S-JTSK',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6156','EPSG','1306',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4157','Mount Dillon',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6157','EPSG','1322',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4158','Naparima 1955',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6158','EPSG','3143',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4159','ELD79',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6159','EPSG','1143',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4160','Chos Malal 1914',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6160','EPSG','1292',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4161','Pampa del Castillo',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6161','EPSG','1265',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4162','Korean 1985',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6162','EPSG','3266',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4163','Yemen NGN96',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6163','EPSG','1257',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4164','South Yemen',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6164','EPSG','1340',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4165','Bissau',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6165','EPSG','3258',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4166','Korean 1995',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6166','EPSG','3266',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4167','NZGD2000',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6167','EPSG','1175',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4168','Accra',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6168','EPSG','1104',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4169','American Samoa 1962',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6169','EPSG','3109',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4170','SIRGAS 1995',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6170','EPSG','3448',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4171','RGF93',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6171','EPSG','1096',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4172','POSGAR',NULL,NULL,'geographic 2D','EPSG','6402','EPSG','6172','EPSG','1033',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4173','IRENET95',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6173','EPSG','1305',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4174','Sierra Leone 1924',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6174','EPSG','1342',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4175','Sierra Leone 1968',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6175','EPSG','3306',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4176','Australian Antarctic',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6176','EPSG','1278',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4178','Pulkovo 1942(83)',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6178','EPSG','3900',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4179','Pulkovo 1942(58)',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6179','EPSG','3574',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4180','EST97',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6180','EPSG','1090',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4181','Luxembourg 1930',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6181','EPSG','1146',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4182','Azores Occidental 1939',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6182','EPSG','1344',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4183','Azores Central 1948',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6183','EPSG','1301',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4184','Azores Oriental 1940',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6184','EPSG','1345',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4185','Madeira 1936',NULL,NULL,'geographic 2D','EPSG','6402','EPSG','6185','EPSG','1314',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4188','OSNI 1952',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6188','EPSG','2530',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4189','REGVEN',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6189','EPSG','1251',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4190','POSGAR 98',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6190','EPSG','1033',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4191','Albanian 1987',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6191','EPSG','3212',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4192','Douala 1948',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6192','EPSG','2555',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4193','Manoca 1962',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6193','EPSG','2555',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4194','Qornoq 1927',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6194','EPSG','3362',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4195','Scoresbysund 1952',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6195','EPSG','2570',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4196','Ammassalik 1958',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6196','EPSG','2571',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4197','Garoua',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6197','EPSG','2590',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4198','Kousseri',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6198','EPSG','2591',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4199','Egypt 1930',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6199','EPSG','3242',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4200','Pulkovo 1995',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6200','EPSG','1198',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4201','Adindan',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6201','EPSG','1271',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4202','AGD66',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6202','EPSG','1279',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4203','AGD84',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6203','EPSG','2576',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4204','Ain el Abd',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6204','EPSG','1272',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4205','Afgooye',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6205','EPSG','3308',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4206','Agadez',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6206','EPSG','1177',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4207','Lisbon',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6207','EPSG','1294',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4208','Aratu',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6208','EPSG','1274',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4209','Arc 1950',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6209','EPSG','1276',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4210','Arc 1960',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6210','EPSG','1277',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4211','Batavia',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6211','EPSG','3666',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4212','Barbados 1938',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6212','EPSG','3218',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4213','Beduaram',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6213','EPSG','2771',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4214','Beijing 1954',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6214','EPSG','1067',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4215','Belge 1950',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6215','EPSG','1347',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4216','Bermuda 1957',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6216','EPSG','3221',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4218','Bogota 1975',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6218','EPSG','3686',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4219','Bukit Rimpah',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6219','EPSG','1287',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4220','Camacupa 1948',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6220','EPSG','1029',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4221','Campo Inchauspe',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6221','EPSG','3843',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4222','Cape',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6222','EPSG','1290',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4223','Carthage',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6223','EPSG','1236',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4224','Chua',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6224','EPSG','3356',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4225','Corrego Alegre 1970-72',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6225','EPSG','1293',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4226','Cote d''Ivoire',NULL,NULL,'geographic 2D','EPSG','6402','EPSG','6226','EPSG','1075',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4227','Deir ez Zor',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6227','EPSG','1623',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4228','Douala',NULL,NULL,'geographic 2D','EPSG','6402','EPSG','6228','EPSG','1060',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4229','Egypt 1907',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6229','EPSG','1086',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4230','ED50',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6230','EPSG','1296',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4231','ED87',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6231','EPSG','1297',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4232','Fahud',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6232','EPSG','4009',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4233','Gandajika 1970',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6233','EPSG','1152',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4234','Garoua',NULL,NULL,'geographic 2D','EPSG','6402','EPSG','6234','EPSG','1060',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4235','Guyane Francaise',NULL,NULL,'geographic 2D','EPSG','6402','EPSG','6235','EPSG','1097',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4236','Hu Tzu Shan 1950',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6236','EPSG','3315',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4237','HD72',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6237','EPSG','1119',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4238','ID74',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6238','EPSG','4020',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4239','Indian 1954',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6239','EPSG','1304',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4240','Indian 1975',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6240','EPSG','3741',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4241','Jamaica 1875',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6241','EPSG','3342',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4242','JAD69',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6242','EPSG','3342',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4243','Kalianpur 1880',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6243','EPSG','1307',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4244','Kandawala',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6244','EPSG','3310',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4245','Kertau 1968',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6245','EPSG','4223',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4246','KOC',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6246','EPSG','3267',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4247','La Canoa',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6247','EPSG','3327',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4248','PSAD56',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6248','EPSG','1348',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4249','Lake',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6249','EPSG','1312',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4250','Leigon',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6250','EPSG','1104',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4251','Liberia 1964',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6251','EPSG','3270',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4252','Lome',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6252','EPSG','1232',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4253','Luzon 1911',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6253','EPSG','3969',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4254','Hito XVIII 1963',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6254','EPSG','1303',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4255','Herat North',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6255','EPSG','1024',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4256','Mahe 1971',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6256','EPSG','2369',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4257','Makassar',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6257','EPSG','1316',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4258','ETRS89',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6258','EPSG','1298',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4259','Malongo 1987',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6259','EPSG','3180',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4260','Manoca',NULL,NULL,'geographic 2D','EPSG','6402','EPSG','6260','EPSG','1060',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4261','Merchich',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6261','EPSG','3280',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4262','Massawa',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6262','EPSG','1089',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4263','Minna',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6263','EPSG','1178',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4264','Mhast',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6264','EPSG','1318',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4265','Monte Mario',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6265','EPSG','3343',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4266','M''poraloko',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6266','EPSG','1100',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4267','NAD27',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6267','EPSG','1349',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4268','NAD27 Michigan',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6268','EPSG','1391',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4269','NAD83',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6269','EPSG','1350',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4270','Nahrwan 1967',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6270','EPSG','1351',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4271','Naparima 1972',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6271','EPSG','1322',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4272','NZGD49',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6272','EPSG','3285',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4273','NGO 1948',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6273','EPSG','1352',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4274','Datum 73',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6274','EPSG','1294',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4275','NTF',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6275','EPSG','3694',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4276','NSWC 9Z-2',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6276','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4277','OSGB 1936',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6277','EPSG','4390',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4278','OSGB70',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6278','EPSG','1264',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4279','OS(SN)80',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6279','EPSG','1354',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4280','Padang',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6280','EPSG','1355',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4281','Palestine 1923',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6281','EPSG','1356',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4282','Pointe Noire',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6282','EPSG','1072',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4283','GDA94',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6283','EPSG','4177',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4284','Pulkovo 1942',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6284','EPSG','2423',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4285','Qatar 1974',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6285','EPSG','1195',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4286','Qatar 1948',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6286','EPSG','1346',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4287','Qornoq',NULL,NULL,'geographic 2D','EPSG','6402','EPSG','6287','EPSG','1107',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4288','Loma Quintana',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6288','EPSG','1313',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4289','Amersfoort',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6289','EPSG','1275',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4291','SAD69',NULL,NULL,'geographic 2D','EPSG','6402','EPSG','6291','EPSG','1358',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4292','Sapper Hill 1943',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6292','EPSG','3247',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4293','Schwarzeck',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6293','EPSG','1169',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4294','Segora',NULL,NULL,'geographic 2D','EPSG','6402','EPSG','6294','EPSG','1359',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4295','Serindung',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6295','EPSG','4005',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4296','Sudan',NULL,NULL,'geographic 2D','EPSG','6402','EPSG','6296','EPSG','1361',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4297','Tananarive',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6297','EPSG','1149',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4298','Timbalai 1948',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6298','EPSG','1362',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4299','TM65',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6299','EPSG','1305',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4300','TM75',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6300','EPSG','1305',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4301','Tokyo',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6301','EPSG','1364',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4302','Trinidad 1903',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6302','EPSG','1339',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4303','TC(1948)',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6303','EPSG','1363',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4304','Voirol 1875',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6304','EPSG','1365',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4306','Bern 1938',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6306','EPSG','1286',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4307','Nord Sahara 1959',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6307','EPSG','1026',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4308','RT38',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6308','EPSG','3313',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4309','Yacare',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6309','EPSG','3326',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4310','Yoff',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6310','EPSG','1207',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4311','Zanderij',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6311','EPSG','1222',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4312','MGI',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6312','EPSG','1037',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4313','Belge 1972',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6313','EPSG','1347',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4314','DHDN',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6314','EPSG','2326',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4315','Conakry 1905',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6315','EPSG','3257',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4316','Dealul Piscului 1930',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6316','EPSG','3295',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4317','Dealul Piscului 1970',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6317','EPSG','1197',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4318','NGN',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6318','EPSG','3267',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4319','KUDAMS',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6319','EPSG','1310',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4322','WGS 72',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6322','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4324','WGS 72BE',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6324','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4326','WGS 84',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6326','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4327','WGS 84 (geographic 3D)',NULL,NULL,'geographic 3D','EPSG','6401','EPSG','6326','EPSG','1262',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4328','WGS 84 (geocentric)',NULL,NULL,'geocentric','EPSG','6500','EPSG','6326','EPSG','1262',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4329','WGS 84 (3D)',NULL,NULL,'geographic 3D','EPSG','6401','EPSG','6326','EPSG','2830',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4330','ITRF88 (geocentric)',NULL,NULL,'geocentric','EPSG','6500','EPSG','6647','EPSG','1262',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4331','ITRF89 (geocentric)',NULL,NULL,'geocentric','EPSG','6500','EPSG','6648','EPSG','1262',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4332','ITRF90 (geocentric)',NULL,NULL,'geocentric','EPSG','6500','EPSG','6649','EPSG','1262',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4333','ITRF91 (geocentric)',NULL,NULL,'geocentric','EPSG','6500','EPSG','6650','EPSG','1262',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4334','ITRF92 (geocentric)',NULL,NULL,'geocentric','EPSG','6500','EPSG','6651','EPSG','1262',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4335','ITRF93 (geocentric)',NULL,NULL,'geocentric','EPSG','6500','EPSG','6652','EPSG','1262',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4336','ITRF94 (geocentric)',NULL,NULL,'geocentric','EPSG','6500','EPSG','6653','EPSG','1262',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4337','ITRF96 (geocentric)',NULL,NULL,'geocentric','EPSG','6500','EPSG','6654','EPSG','1262',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4338','ITRF97 (geocentric)',NULL,NULL,'geocentric','EPSG','6500','EPSG','6655','EPSG','1262',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4339','Australian Antarctic (3D)',NULL,NULL,'geographic 3D','EPSG','6401','EPSG','6176','EPSG','1278',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4340','Australian Antarctic (geocentric)',NULL,NULL,'geocentric','EPSG','6500','EPSG','6176','EPSG','1278',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4341','EST97 (3D)',NULL,NULL,'geographic 3D','EPSG','6401','EPSG','6180','EPSG','1090',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4342','EST97 (geocentric)',NULL,NULL,'geocentric','EPSG','6500','EPSG','6180','EPSG','1090',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4343','CHTRF95 (3D)',NULL,NULL,'geographic 3D','EPSG','6401','EPSG','6151','EPSG','1286',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4344','CHTRF95 (geocentric)',NULL,NULL,'geocentric','EPSG','6500','EPSG','6151','EPSG','1286',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4345','ETRS89 (3D)',NULL,NULL,'geographic 3D','EPSG','6401','EPSG','6258','EPSG','1298',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4346','ETRS89 (geocentric)',NULL,NULL,'geocentric','EPSG','6500','EPSG','6258','EPSG','1298',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4347','GDA94 (3D)',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','6283','EPSG','1036',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4348','GDA94 (geocentric)',NULL,NULL,'geocentric','EPSG','6500','EPSG','6283','EPSG','1036',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4349','Hartebeesthoek94 (3D)',NULL,NULL,'geographic 3D','EPSG','6401','EPSG','6148','EPSG','1215',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4350','Hartebeesthoek94 (geocentric)',NULL,NULL,'geocentric','EPSG','6500','EPSG','6148','EPSG','1215',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4351','IRENET95 (3D)',NULL,NULL,'geographic 3D','EPSG','6401','EPSG','6173','EPSG','1305',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4352','IRENET95 (geocentric)',NULL,NULL,'geocentric','EPSG','6500','EPSG','6173','EPSG','1305',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4353','JGD2000 (3D)',NULL,NULL,'geographic 3D','EPSG','6401','EPSG','6612','EPSG','1129',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4354','JGD2000 (geocentric)',NULL,NULL,'geocentric','EPSG','6500','EPSG','6612','EPSG','1129',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4355','LKS94 (ETRS89) (3D)',NULL,NULL,'geographic 3D','EPSG','6401','EPSG','6126','EPSG','1145',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4356','LKS94 (ETRS89) (geocentric)',NULL,NULL,'geocentric','EPSG','6500','EPSG','6126','EPSG','1145',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4357','Moznet (3D)',NULL,NULL,'geographic 3D','EPSG','6401','EPSG','6130','EPSG','1167',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4358','Moznet (geocentric)',NULL,NULL,'geocentric','EPSG','6500','EPSG','6130','EPSG','1167',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4359','NAD83(CSRS) (3D)',NULL,NULL,'geographic 3D','EPSG','6401','EPSG','6140','EPSG','2784',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4360','NAD83(CSRS) (geocentric)',NULL,NULL,'geocentric','EPSG','6500','EPSG','6140','EPSG','2784',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4361','NAD83(HARN) (3D)',NULL,NULL,'geographic 3D','EPSG','6401','EPSG','6152','EPSG','1337',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4362','NAD83(HARN) (geocentric)',NULL,NULL,'geocentric','EPSG','6500','EPSG','6152','EPSG','1337',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4363','NZGD2000 (3D)',NULL,NULL,'geographic 3D','EPSG','6401','EPSG','6167','EPSG','1175',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4364','NZGD2000 (geocentric)',NULL,NULL,'geocentric','EPSG','6500','EPSG','6167','EPSG','1175',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4365','POSGAR 98 (3D)',NULL,NULL,'geographic 3D','EPSG','6401','EPSG','6190','EPSG','1033',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4366','POSGAR 98 (geocentric)',NULL,NULL,'geocentric','EPSG','6500','EPSG','6190','EPSG','1033',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4367','REGVEN (3D)',NULL,NULL,'geographic 3D','EPSG','6401','EPSG','6189','EPSG','1251',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4368','REGVEN (geocentric)',NULL,NULL,'geocentric','EPSG','6500','EPSG','6189','EPSG','1251',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4369','RGF93 (3D)',NULL,NULL,'geographic 3D','EPSG','6401','EPSG','6171','EPSG','1096',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4370','RGF93 (geocentric)',NULL,NULL,'geocentric','EPSG','6500','EPSG','6171','EPSG','1096',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4371','RGFG95 (3D)',NULL,NULL,'geographic 3D','EPSG','6401','EPSG','6624','EPSG','1097',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4372','RGFG95 (geocentric)',NULL,NULL,'geocentric','EPSG','6500','EPSG','6624','EPSG','1097',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4373','RGR92 (3D)',NULL,NULL,'geographic 3D','EPSG','6401','EPSG','6627','EPSG','1196',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4374','RGR92 (geocentric)',NULL,NULL,'geocentric','EPSG','6500','EPSG','6627','EPSG','1196',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4375','SIRGAS (3D)',NULL,NULL,'geographic 3D','EPSG','6401','EPSG','6170','EPSG','1341',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4376','SIRGAS (geocentric)',NULL,NULL,'geocentric','EPSG','6500','EPSG','6170','EPSG','1341',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4377','SWEREF99 (3D)',NULL,NULL,'geographic 3D','EPSG','6401','EPSG','6619','EPSG','1225',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4378','SWEREF99 (geocentric)',NULL,NULL,'geocentric','EPSG','6500','EPSG','6619','EPSG','1225',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4379','Yemen NGN96 (3D)',NULL,NULL,'geographic 3D','EPSG','6401','EPSG','6163','EPSG','1257',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4380','Yemen NGN96 (geocentric)',NULL,NULL,'geocentric','EPSG','6500','EPSG','6163','EPSG','1257',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4381','RGNC 1991 (3D)',NULL,NULL,'geographic 3D','EPSG','6401','EPSG','6645','EPSG','1174',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4382','RGNC 1991 (geocentric)',NULL,NULL,'geocentric','EPSG','6500','EPSG','6645','EPSG','1174',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4383','RRAF 1991 (3D)',NULL,NULL,'geographic 3D','EPSG','6401','EPSG','6640','EPSG','2824',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4384','RRAF 1991 (geocentric)',NULL,NULL,'geocentric','EPSG','6500','EPSG','6640','EPSG','2824',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4385','ITRF2000 (geocentric)',NULL,NULL,'geocentric','EPSG','6500','EPSG','6656','EPSG','2830',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4386','ISN93 (3D)',NULL,NULL,'geographic 3D','EPSG','6401','EPSG','6659','EPSG','1120',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4387','ISN93 (geocentric)',NULL,NULL,'geocentric','EPSG','6500','EPSG','6659','EPSG','1120',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4388','LKS92 (3D)',NULL,NULL,'geographic 3D','EPSG','6401','EPSG','6661','EPSG','1139',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4389','LKS92 (geocentric)',NULL,NULL,'geocentric','EPSG','6500','EPSG','6661','EPSG','1139',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4463','RGSPM06',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1038','EPSG','1220',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4465','RGSPM06',NULL,NULL,'geocentric','EPSG','6500','EPSG','1038','EPSG','1220',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4466','RGSPM06',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1038','EPSG','1220',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4468','RGM04',NULL,NULL,'geocentric','EPSG','6500','EPSG','1036','EPSG','1159',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4469','RGM04',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1036','EPSG','1159',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4470','RGM04',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1036','EPSG','1159',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4472','Cadastre 1997',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1037','EPSG','3340',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4473','Cadastre 1997',NULL,NULL,'geocentric','EPSG','6500','EPSG','1037','EPSG','3340',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4475','Cadastre 1997',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1037','EPSG','3340',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4479','China Geodetic Coordinate System 2000',NULL,NULL,'geocentric','EPSG','6500','EPSG','1043','EPSG','1067',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4480','China Geodetic Coordinate System 2000',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1043','EPSG','1067',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4481','Mexico ITRF92',NULL,NULL,'geocentric','EPSG','6500','EPSG','1042','EPSG','1160',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4482','Mexico ITRF92',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1042','EPSG','1160',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4483','Mexico ITRF92',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1042','EPSG','1160',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4490','China Geodetic Coordinate System 2000',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1043','EPSG','1067',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4555','New Beijing',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1045','EPSG','3228',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4556','RRAF 1991',NULL,NULL,'geocentric','EPSG','6500','EPSG','1047','EPSG','2824',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4557','RRAF 1991',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1047','EPSG','2824',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4558','RRAF 1991',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1047','EPSG','2824',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4600','Anguilla 1957',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6600','EPSG','3214',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4601','Antigua 1943',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6601','EPSG','1273',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4602','Dominica 1945',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6602','EPSG','3239',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4603','Grenada 1953',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6603','EPSG','1551',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4604','Montserrat 1958',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6604','EPSG','3279',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4605','St. Kitts 1955',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6605','EPSG','3297',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4606','St. Lucia 1955',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6606','EPSG','3298',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4607','St. Vincent 1945',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6607','EPSG','3300',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4608','NAD27(76)',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6608','EPSG','1367',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4609','NAD27(CGQ77)',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6609','EPSG','1368',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4610','Xian 1980',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6610','EPSG','3228',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4611','Hong Kong 1980',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6611','EPSG','1118',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4612','JGD2000',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6612','EPSG','1129',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4613','Segara',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6613','EPSG','1360',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4614','QND95',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6614','EPSG','1346',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4615','Porto Santo',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6615','EPSG','1314',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4616','Selvagem Grande',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6616','EPSG','2779',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4617','NAD83(CSRS)',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6140','EPSG','1061',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4618','SAD69',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6618','EPSG','1358',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4619','SWEREF99',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6619','EPSG','1225',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4620','Point 58',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6620','EPSG','2790',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4621','Fort Marigot',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6621','EPSG','2828',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4622','Guadeloupe 1948',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6622','EPSG','2829',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4623','CSG67',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6623','EPSG','3105',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4624','RGFG95',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6624','EPSG','1097',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4625','Martinique 1938',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6625','EPSG','3276',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4626','Reunion 1947',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6626','EPSG','3337',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4627','RGR92',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6627','EPSG','3902',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4628','Tahiti 52',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6628','EPSG','2811',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4629','Tahaa 54',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6629','EPSG','2812',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4630','IGN72 Nuku Hiva',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6630','EPSG','3129',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4631','K0 1949',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6631','EPSG','2816',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4632','Combani 1950',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6632','EPSG','3340',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4633','IGN56 Lifou',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6633','EPSG','2814',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4634','IGN72 Grand Terre',NULL,NULL,'geographic 2D','EPSG','6402','EPSG','6634','EPSG','2822',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4635','ST87 Ouvea',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6635','EPSG','2813',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4636','Petrels 1972',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6636','EPSG','2817',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4637','Perroud 1950',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6637','EPSG','2818',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4638','Saint Pierre et Miquelon 1950',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6638','EPSG','3299',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4639','MOP78',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6639','EPSG','2815',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4640','RRAF 1991',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6640','EPSG','2824',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4641','IGN53 Mare',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6641','EPSG','2819',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4642','ST84 Ile des Pins',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6642','EPSG','2820',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4643','ST71 Belep',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6643','EPSG','2821',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4644','NEA74 Noumea',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6644','EPSG','2823',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4645','RGNC 1991',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6645','EPSG','1174',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4646','Grand Comoros',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6646','EPSG','2807',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4657','Reykjavik 1900',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6657','EPSG','3262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4658','Hjorsey 1955',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6658','EPSG','3262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4659','ISN93',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6659','EPSG','1120',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4660','Helle 1954',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6660','EPSG','2869',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4661','LKS92',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6661','EPSG','1139',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4662','IGN72 Grande Terre',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6634','EPSG','2822',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4663','Porto Santo 1995',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6663','EPSG','1314',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4664','Azores Oriental 1995',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6664','EPSG','1345',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4665','Azores Central 1995',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6665','EPSG','1301',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4666','Lisbon 1890',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6666','EPSG','1294',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4667','IKBD-92',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6667','EPSG','2876',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4668','ED79',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6668','EPSG','1297',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4669','LKS94',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6126','EPSG','1145',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4670','IGM95',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6670','EPSG','3343',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4671','Voirol 1879',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6671','EPSG','1365',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4672','Chatham Islands 1971',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6672','EPSG','2889',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4673','Chatham Islands 1979',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6673','EPSG','2889',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4674','SIRGAS 2000',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6674','EPSG','3418',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4675','Guam 1963',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6675','EPSG','4525',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4676','Vientiane 1982',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6676','EPSG','1138',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4677','Lao 1993',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6677','EPSG','1138',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4678','Lao 1997',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6678','EPSG','1138',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4679','Jouik 1961',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6679','EPSG','2967',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4680','Nouakchott 1965',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6680','EPSG','2968',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4681','Mauritania 1999',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6681','EPSG','1157',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4682','Gulshan 303',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6682','EPSG','1041',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4683','PRS92',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6683','EPSG','1190',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4684','Gan 1970',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6684','EPSG','3274',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4685','Gandajika',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6685','EPSG','1259',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4686','MAGNA-SIRGAS',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6686','EPSG','1070',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4687','RGPF',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6687','EPSG','1098',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4688','Fatu Iva 72',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6688','EPSG','3133',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4689','IGN63 Hiva Oa',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6689','EPSG','3130',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4690','Tahiti 79',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6690','EPSG','3124',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4691','Moorea 87',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6691','EPSG','3125',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4692','Maupiti 83',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6692','EPSG','3126',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4693','Nakhl-e Ghanem',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6693','EPSG','2362',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4694','POSGAR 94',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6694','EPSG','1033',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4695','Katanga 1955',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6695','EPSG','3147',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4696','Kasai 1953',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6696','EPSG','3148',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4697','IGC 1962 6th Parallel South',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6697','EPSG','3149',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4698','IGN 1962 Kerguelen',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6698','EPSG','2816',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4699','Le Pouce 1934',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6699','EPSG','3209',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4700','IGN Astro 1960',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6700','EPSG','3277',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4701','IGCB 1955',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6701','EPSG','3171',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4702','Mauritania 1999',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6702','EPSG','1157',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4703','Mhast 1951',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6703','EPSG','1318',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4704','Mhast (onshore)',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6704','EPSG','3179',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4705','Mhast (offshore)',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6705','EPSG','3180',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4706','Egypt Gulf of Suez S-650 TL',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6706','EPSG','2341',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4707','Tern Island 1961',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6707','EPSG','3181',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4708','Cocos Islands 1965',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6708','EPSG','1069',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4709','Iwo Jima 1945',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6709','EPSG','3200',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4710','Astro DOS 71',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6710','EPSG','3183',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4711','Marcus Island 1952',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6711','EPSG','1872',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4712','Ascension Island 1958',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6712','EPSG','3182',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4713','Ayabelle Lighthouse',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6713','EPSG','1081',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4714','Bellevue',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6714','EPSG','3193',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4715','Camp Area Astro',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6715','EPSG','3205',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4716','Phoenix Islands 1966',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6716','EPSG','3196',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4717','Cape Canaveral',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6717','EPSG','3206',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4718','Solomon 1968',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6718','EPSG','1213',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4719','Easter Island 1967',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6719','EPSG','3188',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4720','Fiji 1986',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6720','EPSG','1094',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4721','Fiji 1956',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6721','EPSG','3398',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4722','South Georgia 1968',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6722','EPSG','3529',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4723','GCGD59',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6723','EPSG','3185',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4724','Diego Garcia 1969',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6724','EPSG','3189',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4725','Johnston Island 1961',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6725','EPSG','3201',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4726','SIGD61',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6726','EPSG','3186',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4727','Midway 1961',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6727','EPSG','3202',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4728','Pico de las Nieves 1984',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6728','EPSG','3873',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4729','Pitcairn 1967',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6729','EPSG','3208',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4730','Santo 1965',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6730','EPSG','3194',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4731','Viti Levu 1916',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6731','EPSG','3195',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4732','Marshall Islands 1960',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6732','EPSG','3191',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4733','Wake Island 1952',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6733','EPSG','3190',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4734','Tristan 1968',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6734','EPSG','3184',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4735','Kusaie 1951',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6735','EPSG','3192',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4736','Deception Island',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6736','EPSG','3204',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4737','Korea 2000',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6737','EPSG','1135',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4738','Hong Kong 1963',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6738','EPSG','1118',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4739','Hong Kong 1963(67)',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6739','EPSG','1118',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4740','PZ-90',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6740','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4741','FD54',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6741','EPSG','3248',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4742','GDM2000',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6742','EPSG','1151',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4743','Karbala 1979',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6743','EPSG','3625',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4744','Nahrwan 1934',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6744','EPSG','4238',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4745','RD/83',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6745','EPSG','2545',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4746','PD/83',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6746','EPSG','2544',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4747','GR96',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6747','EPSG','1107',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4748','Vanua Levu 1915',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6748','EPSG','3401',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4749','RGNC91-93',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6749','EPSG','1174',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4750','ST87 Ouvea',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6750','EPSG','2813',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4751','Kertau (RSO)',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6751','EPSG','1309',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4752','Viti Levu 1912',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6752','EPSG','3195',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4753','fk89',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6753','EPSG','3248',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4754','LGD2006',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6754','EPSG','1143',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4755','DGN95',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6755','EPSG','1122',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4756','VN-2000',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6756','EPSG','3328',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4757','SVY21',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6757','EPSG','1210',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4758','JAD2001',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6758','EPSG','1128',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4759','NAD83(NSRS2007)',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6759','EPSG','1511',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4760','WGS 66',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6760','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4761','HTRS96',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6761','EPSG','1076',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4762','BDA2000',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6762','EPSG','1047',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4763','Pitcairn 2006',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6763','EPSG','3208',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4764','RSRGD2000',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6764','EPSG','3558',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4765','Slovenia 1996',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6765','EPSG','1212',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4801','Bern 1898 (Bern)',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6801','EPSG','1286',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4802','Bogota 1975 (Bogota)',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6802','EPSG','3229',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4803','Lisbon (Lisbon)',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6803','EPSG','1294',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4804','Makassar (Jakarta)',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6804','EPSG','1316',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4805','MGI (Ferro)',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6805','EPSG','1321',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4806','Monte Mario (Rome)',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6806','EPSG','3343',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4807','NTF (Paris)',NULL,NULL,'geographic 2D','EPSG','6403','EPSG','6807','EPSG','3694',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4808','Padang (Jakarta)',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6808','EPSG','1355',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4809','Belge 1950 (Brussels)',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6809','EPSG','1347',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4810','Tananarive (Paris)',NULL,NULL,'geographic 2D','EPSG','6403','EPSG','6810','EPSG','3273',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4811','Voirol 1875 (Paris)',NULL,NULL,'geographic 2D','EPSG','6403','EPSG','6811','EPSG','1365',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4813','Batavia (Jakarta)',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6813','EPSG','1285',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4814','RT38 (Stockholm)',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6814','EPSG','3313',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4815','Greek (Athens)',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6815','EPSG','3254',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4816','Carthage (Paris)',NULL,NULL,'geographic 2D','EPSG','6403','EPSG','6816','EPSG','1618',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4817','NGO 1948 (Oslo)',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6817','EPSG','1352',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4818','S-JTSK (Ferro)',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6818','EPSG','1306',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4819','Nord Sahara 1959 (Paris)',NULL,NULL,'geographic 2D','EPSG','6403','EPSG','6819','EPSG','1366',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4820','Segara (Jakarta)',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6820','EPSG','1360',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4821','Voirol 1879 (Paris)',NULL,NULL,'geographic 2D','EPSG','6403','EPSG','6821','EPSG','1365',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4823','Sao Tome',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1044','EPSG','3645',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4824','Principe',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1046','EPSG','3646',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4882','Slovenia 1996',NULL,NULL,'geocentric','EPSG','6500','EPSG','6765','EPSG','1212',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4883','Slovenia 1996',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','6765','EPSG','1212',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4884','RSRGD2000',NULL,NULL,'geocentric','EPSG','6500','EPSG','6764','EPSG','3558',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4885','RSRGD2000',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','6764','EPSG','3558',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4886','BDA2000',NULL,NULL,'geocentric','EPSG','6500','EPSG','6762','EPSG','1047',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4887','BDA2000',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','6762','EPSG','1047',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4888','HTRS96',NULL,NULL,'geocentric','EPSG','6500','EPSG','6761','EPSG','1076',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4889','HTRS96',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','6761','EPSG','1076',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4890','WGS 66',NULL,NULL,'geocentric','EPSG','6500','EPSG','6760','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4891','WGS 66',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','6760','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4892','NAD83(NSRS2007)',NULL,NULL,'geocentric','EPSG','6500','EPSG','6759','EPSG','1511',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4893','NAD83(NSRS2007)',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','6759','EPSG','1511',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4894','JAD2001',NULL,NULL,'geocentric','EPSG','6500','EPSG','6758','EPSG','1128',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4895','JAD2001',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','6758','EPSG','1128',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4896','ITRF2005',NULL,NULL,'geocentric','EPSG','6500','EPSG','6896','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4897','DGN95',NULL,NULL,'geocentric','EPSG','6500','EPSG','6755','EPSG','1122',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4898','DGN95',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','6755','EPSG','1122',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4899','LGD2006',NULL,NULL,'geocentric','EPSG','6500','EPSG','6754','EPSG','1143',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4900','LGD2006',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','6754','EPSG','1143',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4901','ATF (Paris)',NULL,NULL,'geographic 2D','EPSG','6403','EPSG','6901','EPSG','1326',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4902','NDG (Paris)',NULL,NULL,'geographic 2D','EPSG','6403','EPSG','6902','EPSG','1369',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4903','Madrid 1870 (Madrid)',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6903','EPSG','2366',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4904','Lisbon 1890 (Lisbon)',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6904','EPSG','1294',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4906','RGNC91-93',NULL,NULL,'geocentric','EPSG','6500','EPSG','6749','EPSG','1174',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4907','RGNC91-93',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','6749','EPSG','1174',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4908','GR96',NULL,NULL,'geocentric','EPSG','6500','EPSG','6747','EPSG','1107',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4909','GR96',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','6747','EPSG','1107',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4910','ITRF88',NULL,NULL,'geocentric','EPSG','6500','EPSG','6647','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4911','ITRF89',NULL,NULL,'geocentric','EPSG','6500','EPSG','6648','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4912','ITRF90',NULL,NULL,'geocentric','EPSG','6500','EPSG','6649','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4913','ITRF91',NULL,NULL,'geocentric','EPSG','6500','EPSG','6650','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4914','ITRF92',NULL,NULL,'geocentric','EPSG','6500','EPSG','6651','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4915','ITRF93',NULL,NULL,'geocentric','EPSG','6500','EPSG','6652','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4916','ITRF94',NULL,NULL,'geocentric','EPSG','6500','EPSG','6653','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4917','ITRF96',NULL,NULL,'geocentric','EPSG','6500','EPSG','6654','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4918','ITRF97',NULL,NULL,'geocentric','EPSG','6500','EPSG','6655','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4919','ITRF2000',NULL,NULL,'geocentric','EPSG','6500','EPSG','6656','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4920','GDM2000',NULL,NULL,'geocentric','EPSG','6500','EPSG','6742','EPSG','1151',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4921','GDM2000',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','6742','EPSG','1151',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4922','PZ-90',NULL,NULL,'geocentric','EPSG','6500','EPSG','6740','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4923','PZ-90',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','6740','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4924','Mauritania 1999',NULL,NULL,'geocentric','EPSG','6500','EPSG','6702','EPSG','1157',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4925','Mauritania 1999',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','6702','EPSG','1157',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4926','Korea 2000',NULL,NULL,'geocentric','EPSG','6500','EPSG','6737','EPSG','1135',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4927','Korea 2000',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','6737','EPSG','1135',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4928','POSGAR 94',NULL,NULL,'geocentric','EPSG','6500','EPSG','6694','EPSG','1033',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4929','POSGAR 94',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','6694','EPSG','1033',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4930','Australian Antarctic',NULL,NULL,'geocentric','EPSG','6500','EPSG','6176','EPSG','1278',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4931','Australian Antarctic',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','6176','EPSG','1278',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4932','CHTRF95',NULL,NULL,'geocentric','EPSG','6500','EPSG','6151','EPSG','1286',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4933','CHTRF95',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','6151','EPSG','1286',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4934','EST97',NULL,NULL,'geocentric','EPSG','6500','EPSG','6180','EPSG','1090',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4935','EST97',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','6180','EPSG','1090',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4936','ETRS89',NULL,NULL,'geocentric','EPSG','6500','EPSG','6258','EPSG','1298',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4937','ETRS89',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','6258','EPSG','1298',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4938','GDA94',NULL,NULL,'geocentric','EPSG','6500','EPSG','6283','EPSG','4177',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4939','GDA94',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','6283','EPSG','4177',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4940','Hartebeesthoek94',NULL,NULL,'geocentric','EPSG','6500','EPSG','6148','EPSG','4540',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4941','Hartebeesthoek94',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','6148','EPSG','4540',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4942','IRENET95',NULL,NULL,'geocentric','EPSG','6500','EPSG','6173','EPSG','1305',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4943','IRENET95',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','6173','EPSG','1305',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4944','ISN93',NULL,NULL,'geocentric','EPSG','6500','EPSG','6659','EPSG','1120',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4945','ISN93',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','6659','EPSG','1120',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4946','JGD2000',NULL,NULL,'geocentric','EPSG','6500','EPSG','6612','EPSG','1129',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4947','JGD2000',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','6612','EPSG','1129',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4948','LKS92',NULL,NULL,'geocentric','EPSG','6500','EPSG','6661','EPSG','1139',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4949','LKS92',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','6661','EPSG','1139',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4950','LKS94',NULL,NULL,'geocentric','EPSG','6500','EPSG','6126','EPSG','1145',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4951','LKS94',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','6126','EPSG','1145',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4952','Moznet',NULL,NULL,'geocentric','EPSG','6500','EPSG','6130','EPSG','1167',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4953','Moznet',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','6130','EPSG','1167',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4954','NAD83(CSRS)',NULL,NULL,'geocentric','EPSG','6500','EPSG','6140','EPSG','1061',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4955','NAD83(CSRS)',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','6140','EPSG','1061',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4956','NAD83(HARN)',NULL,NULL,'geocentric','EPSG','6500','EPSG','6152','EPSG','1337',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4957','NAD83(HARN)',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','6152','EPSG','1337',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4958','NZGD2000',NULL,NULL,'geocentric','EPSG','6500','EPSG','6167','EPSG','1175',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4959','NZGD2000',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','6167','EPSG','1175',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4960','POSGAR 98',NULL,NULL,'geocentric','EPSG','6500','EPSG','6190','EPSG','1033',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4961','POSGAR 98',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','6190','EPSG','1033',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4962','REGVEN',NULL,NULL,'geocentric','EPSG','6500','EPSG','6189','EPSG','1251',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4963','REGVEN',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','6189','EPSG','1251',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4964','RGF93',NULL,NULL,'geocentric','EPSG','6500','EPSG','6171','EPSG','1096',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4965','RGF93',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','6171','EPSG','1096',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4966','RGFG95',NULL,NULL,'geocentric','EPSG','6500','EPSG','6624','EPSG','1097',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4967','RGFG95',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','6624','EPSG','1097',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4968','RGNC 1991',NULL,NULL,'geocentric','EPSG','6500','EPSG','6645','EPSG','1174',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4969','RGNC 1991',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','6645','EPSG','1174',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4970','RGR92',NULL,NULL,'geocentric','EPSG','6500','EPSG','6627','EPSG','3902',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4971','RGR92',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','6627','EPSG','3902',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4972','RRAF 1991',NULL,NULL,'geocentric','EPSG','6500','EPSG','6640','EPSG','2824',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4973','RRAF 1991',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','6640','EPSG','2824',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','4974','SIRGAS 1995',NULL,NULL,'geocentric','EPSG','6500','EPSG','6170','EPSG','3448',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4975','SIRGAS 1995',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','6170','EPSG','3448',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4976','SWEREF99',NULL,NULL,'geocentric','EPSG','6500','EPSG','6619','EPSG','1225',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4977','SWEREF99',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','6619','EPSG','1225',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4978','WGS 84',NULL,NULL,'geocentric','EPSG','6500','EPSG','6326','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4979','WGS 84',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','6326','EPSG','2830',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4980','Yemen NGN96',NULL,NULL,'geocentric','EPSG','6500','EPSG','6163','EPSG','1257',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4981','Yemen NGN96',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','6163','EPSG','1257',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4982','IGM95',NULL,NULL,'geocentric','EPSG','6500','EPSG','6670','EPSG','3343',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4983','IGM95',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','6670','EPSG','3343',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4984','WGS 72',NULL,NULL,'geocentric','EPSG','6500','EPSG','6322','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4985','WGS 72',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','6322','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4986','WGS 72BE',NULL,NULL,'geocentric','EPSG','6500','EPSG','6324','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4987','WGS 72BE',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','6324','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4988','SIRGAS 2000',NULL,NULL,'geocentric','EPSG','6500','EPSG','6674','EPSG','3418',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4989','SIRGAS 2000',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','6674','EPSG','3418',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4990','Lao 1993',NULL,NULL,'geocentric','EPSG','6500','EPSG','6677','EPSG','1138',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4991','Lao 1993',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','6677','EPSG','1138',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4992','Lao 1997',NULL,NULL,'geocentric','EPSG','6500','EPSG','6678','EPSG','1138',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4993','Lao 1997',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','6678','EPSG','1138',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4994','PRS92',NULL,NULL,'geocentric','EPSG','6500','EPSG','6683','EPSG','1190',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4995','PRS92',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','6683','EPSG','1190',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4996','MAGNA-SIRGAS',NULL,NULL,'geocentric','EPSG','6500','EPSG','6686','EPSG','1070',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4997','MAGNA-SIRGAS',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','6686','EPSG','1070',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4998','RGPF',NULL,NULL,'geocentric','EPSG','6500','EPSG','6687','EPSG','1098',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','4999','RGPF',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','6687','EPSG','1098',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','5011','PTRA08',NULL,NULL,'geocentric','EPSG','6500','EPSG','1041','EPSG','3670',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','5012','PTRA08',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1041','EPSG','3670',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','5013','PTRA08',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1041','EPSG','3670',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','5132','Tokyo 1892',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1048','EPSG','1364',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','5228','S-JTSK/05',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1052','EPSG','1079',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','5229','S-JTSK/05 (Ferro)',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1055','EPSG','1079',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','5233','SLD99',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1053','EPSG','3310',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','5244','GDBD2009',NULL,NULL,'geocentric','EPSG','6500','EPSG','1056','EPSG','1055',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','5245','GDBD2009',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1056','EPSG','1055',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','5246','GDBD2009',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1056','EPSG','1055',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','5250','TUREF',NULL,NULL,'geocentric','EPSG','6500','EPSG','1057','EPSG','1237',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','5251','TUREF',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1057','EPSG','1237',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','5252','TUREF',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1057','EPSG','1237',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','5262','DRUKREF 03',NULL,NULL,'geocentric','EPSG','6500','EPSG','1058','EPSG','1048',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','5263','DRUKREF 03',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1058','EPSG','1048',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','5264','DRUKREF 03',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1058','EPSG','1048',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','5322','ISN2004',NULL,NULL,'geocentric','EPSG','6500','EPSG','1060','EPSG','1120',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','5323','ISN2004',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1060','EPSG','1120',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','5324','ISN2004',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1060','EPSG','1120',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','5332','ITRF2008',NULL,NULL,'geocentric','EPSG','6500','EPSG','1061','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','5340','POSGAR 2007',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1062','EPSG','1033',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','5341','POSGAR 2007',NULL,NULL,'geocentric','EPSG','6500','EPSG','1062','EPSG','1033',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','5342','POSGAR 2007',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1062','EPSG','1033',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','5352','MARGEN',NULL,NULL,'geocentric','EPSG','6500','EPSG','1063','EPSG','1049',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','5353','MARGEN',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1063','EPSG','1049',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','5354','MARGEN',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1063','EPSG','1049',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','5358','SIRGAS-Chile 2002',NULL,NULL,'geocentric','EPSG','6500','EPSG','1064','EPSG','1066',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','5359','SIRGAS-Chile 2002',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1064','EPSG','1066',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','5360','SIRGAS-Chile 2002',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1064','EPSG','1066',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','5363','CR05',NULL,NULL,'geocentric','EPSG','6500','EPSG','1065','EPSG','1074',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','5364','CR05',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1065','EPSG','1074',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','5365','CR05',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1065','EPSG','1074',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','5368','MACARIO SOLIS',NULL,NULL,'geocentric','EPSG','6500','EPSG','1066','EPSG','1186',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','5369','Peru96',NULL,NULL,'geocentric','EPSG','6500','EPSG','1067','EPSG','1189',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','5370','MACARIO SOLIS',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1066','EPSG','1186',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','5371','MACARIO SOLIS',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1066','EPSG','1186',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','5372','Peru96',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1067','EPSG','1189',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','5373','Peru96',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1067','EPSG','1189',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','5379','SIRGAS-ROU98',NULL,NULL,'geocentric','EPSG','6500','EPSG','1068','EPSG','1247',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','5380','SIRGAS-ROU98',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1068','EPSG','1247',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','5381','SIRGAS-ROU98',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1068','EPSG','1247',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','5391','SIRGAS_ES2007.8',NULL,NULL,'geocentric','EPSG','6500','EPSG','1069','EPSG','1087',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','5392','SIRGAS_ES2007.8',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1069','EPSG','1087',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','5393','SIRGAS_ES2007.8',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1069','EPSG','1087',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','5451','Ocotepeque 1935',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1070','EPSG','3876',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','5464','Sibun Gorge 1922',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1071','EPSG','3219',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','5467','Panama-Colon 1911',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1072','EPSG','3290',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','5487','RGAF09',NULL,NULL,'geocentric','EPSG','6500','EPSG','1073','EPSG','2824',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','5488','RGAF09',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1073','EPSG','2824',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','5489','RGAF09',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1073','EPSG','2824',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','5524','Corrego Alegre 1961',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1074','EPSG','3874',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','5527','SAD69(96)',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1075','EPSG','1053',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','5544','PNG94',NULL,NULL,'geocentric','EPSG','6500','EPSG','1076','EPSG','1187',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','5545','PNG94',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1076','EPSG','1187',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','5546','PNG94',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1076','EPSG','1187',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','5558','UCS-2000',NULL,NULL,'geocentric','EPSG','6500','EPSG','1077','EPSG','1242',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','5560','UCS-2000',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1077','EPSG','1242',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','5561','UCS-2000',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1077','EPSG','1242',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','5591','FEH2010',NULL,NULL,'geocentric','EPSG','6500','EPSG','1078','EPSG','3889',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','5592','FEH2010',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1078','EPSG','3889',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','5593','FEH2010',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1078','EPSG','3889',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','5681','DB_REF',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1081','EPSG','3339',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','5828','DB_REF',NULL,NULL,'geocentric','EPSG','6500','EPSG','1081','EPSG','3339',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','5830','DB_REF',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1081','EPSG','3339',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','5884','TGD2005',NULL,NULL,'geocentric','EPSG','6500','EPSG','1095','EPSG','1234',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','5885','TGD2005',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1095','EPSG','1234',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','5886','TGD2005',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1095','EPSG','1234',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','6133','CIGD11',NULL,NULL,'geocentric','EPSG','6500','EPSG','1100','EPSG','1063',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','6134','CIGD11',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1100','EPSG','1063',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','6135','CIGD11',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1100','EPSG','1063',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','6207','Nepal 1981',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1111','EPSG','1171',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','6309','CGRS93',NULL,NULL,'geocentric','EPSG','6500','EPSG','1112','EPSG','3236',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','6310','CGRS93',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1112','EPSG','3236',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','6311','CGRS93',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1112','EPSG','3236',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','6317','NAD83(2011)',NULL,NULL,'geocentric','EPSG','6500','EPSG','1116','EPSG','1511',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','6318','NAD83(2011)',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1116','EPSG','1511',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','6319','NAD83(2011)',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1116','EPSG','1511',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','6320','NAD83(PA11)',NULL,NULL,'geocentric','EPSG','6500','EPSG','1117','EPSG','4162',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','6321','NAD83(PA11)',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1117','EPSG','4162',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','6322','NAD83(PA11)',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1117','EPSG','4162',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','6323','NAD83(MA11)',NULL,NULL,'geocentric','EPSG','6500','EPSG','1118','EPSG','4167',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','6324','NAD83(MA11)',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1118','EPSG','4167',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','6325','NAD83(MA11)',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1118','EPSG','4167',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','6363','Mexico ITRF2008',NULL,NULL,'geocentric','EPSG','6500','EPSG','1120','EPSG','1160',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','6364','Mexico ITRF2008',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1120','EPSG','1160',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','6365','Mexico ITRF2008',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1120','EPSG','1160',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','6666','JGD2011',NULL,NULL,'geocentric','EPSG','6500','EPSG','1128','EPSG','1129',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','6667','JGD2011',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1128','EPSG','1129',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','6668','JGD2011',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1128','EPSG','1129',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','6704','RDN2008',NULL,NULL,'geocentric','EPSG','6500','EPSG','1132','EPSG','3343',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','6705','RDN2008',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1132','EPSG','3343',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','6706','RDN2008',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1132','EPSG','3343',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','6781','NAD83(CORS96)',NULL,NULL,'geocentric','EPSG','6500','EPSG','1133','EPSG','1511',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','6782','NAD83(CORS96)',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1133','EPSG','1511',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','6783','NAD83(CORS96)',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1133','EPSG','1511',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','6881','Aden 1925',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1135','EPSG','1340',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','6882','Bekaa Valley 1920',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1137','EPSG','3269',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','6883','Bioko',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1136','EPSG','4220',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','6892','South East Island 1943',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1138','EPSG','4183',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','6894','Gambia',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1139','EPSG','3250',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','6934','IGS08',NULL,NULL,'geocentric','EPSG','6500','EPSG','1141','EPSG','2830',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','6978','IGD05',NULL,NULL,'geocentric','EPSG','6500','EPSG','1143','EPSG','1126',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','6979','IGD05',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1143','EPSG','1126',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','6980','IGD05',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1143','EPSG','1126',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','6981','IG05 Intermediate CRS',NULL,NULL,'geocentric','EPSG','6500','EPSG','1142','EPSG','2603',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','6982','IG05 Intermediate CRS',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1142','EPSG','2603',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','6983','IG05 Intermediate CRS',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1142','EPSG','2603',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','6985','IGD05/12',NULL,NULL,'geocentric','EPSG','6500','EPSG','1145','EPSG','1126',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','6986','IGD05/12',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1145','EPSG','1126',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','6987','IGD05/12',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1145','EPSG','1126',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','6988','IG05/12 Intermediate CRS',NULL,NULL,'geocentric','EPSG','6500','EPSG','1144','EPSG','2603',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','6989','IG05/12 Intermediate CRS',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1144','EPSG','2603',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','6990','IG05/12 Intermediate CRS',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1144','EPSG','2603',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7034','RGSPM06 (lon-lat)',NULL,NULL,'geographic 3D','EPSG','6426','EPSG','1038','EPSG','1220',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7035','RGSPM06 (lon-lat)',NULL,NULL,'geographic 2D','EPSG','6424','EPSG','1038','EPSG','1220',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7036','RGR92 (lon-lat)',NULL,NULL,'geographic 3D','EPSG','6426','EPSG','6627','EPSG','3902',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7037','RGR92 (lon-lat)',NULL,NULL,'geographic 2D','EPSG','6424','EPSG','6627','EPSG','3902',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7038','RGM04 (lon-lat)',NULL,NULL,'geographic 3D','EPSG','6426','EPSG','1036','EPSG','1159',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7039','RGM04 (lon-lat)',NULL,NULL,'geographic 2D','EPSG','6424','EPSG','1036','EPSG','1159',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7040','RGFG95 (lon-lat)',NULL,NULL,'geographic 3D','EPSG','6426','EPSG','6624','EPSG','1097',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7041','RGFG95 (lon-lat)',NULL,NULL,'geographic 2D','EPSG','6424','EPSG','6624','EPSG','1097',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7042','RGF93 (lon-lat)',NULL,NULL,'geographic 3D','EPSG','6426','EPSG','6171','EPSG','1096',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7071','RGTAAF07',NULL,NULL,'geocentric','EPSG','6500','EPSG','1113','EPSG','4246',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7072','RGTAAF07',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1113','EPSG','4246',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7073','RGTAAF07',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1113','EPSG','4246',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7084','RGF93 (lon-lat)',NULL,NULL,'geographic 2D','EPSG','6424','EPSG','6171','EPSG','1096',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7085','RGAF09 (lon-lat)',NULL,NULL,'geographic 3D','EPSG','6426','EPSG','1073','EPSG','2824',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7086','RGAF09 (lon-lat)',NULL,NULL,'geographic 2D','EPSG','6424','EPSG','1073','EPSG','2824',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7087','RGTAAF07 (lon-lat)',NULL,NULL,'geographic 3D','EPSG','6426','EPSG','1113','EPSG','4246',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7088','RGTAAF07 (lon-lat)',NULL,NULL,'geographic 2D','EPSG','6424','EPSG','1113','EPSG','4246',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','7133','RGTAAF07 (lon-lat)',NULL,NULL,'geographic 2D','EPSG','6424','EPSG','1113','EPSG','4246',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7134','IGD05',NULL,NULL,'geocentric','EPSG','6500','EPSG','1114','EPSG','1126',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7135','IGD05',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1114','EPSG','1126',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7136','IGD05',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1114','EPSG','1126',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7137','IGD05/12',NULL,NULL,'geocentric','EPSG','6500','EPSG','1115','EPSG','1126',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7138','IGD05/12',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1115','EPSG','1126',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7139','IGD05/12',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1115','EPSG','1126',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7371','ONGD14',NULL,NULL,'geocentric','EPSG','6500','EPSG','1147','EPSG','1183',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7372','ONGD14',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1147','EPSG','1183',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7373','ONGD14',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1147','EPSG','1183',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7656','WGS 84 (G730)',NULL,NULL,'geocentric','EPSG','6500','EPSG','1152','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7657','WGS 84 (G730)',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1152','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7658','WGS 84 (G873)',NULL,NULL,'geocentric','EPSG','6500','EPSG','1153','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7659','WGS 84 (G873)',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1153','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7660','WGS 84 (G1150)',NULL,NULL,'geocentric','EPSG','6500','EPSG','1154','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7661','WGS 84 (G1150)',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1154','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7662','WGS 84 (G1674)',NULL,NULL,'geocentric','EPSG','6500','EPSG','1155','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7663','WGS 84 (G1674)',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1155','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7664','WGS 84 (G1762)',NULL,NULL,'geocentric','EPSG','6500','EPSG','1156','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7665','WGS 84 (G1762)',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1156','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7677','PZ-90.02',NULL,NULL,'geocentric','EPSG','6500','EPSG','1157','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7678','PZ-90.02',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1157','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7679','PZ-90.11',NULL,NULL,'geocentric','EPSG','6500','EPSG','1158','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7680','PZ-90.11',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1158','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7681','GSK-2011',NULL,NULL,'geocentric','EPSG','6500','EPSG','1159','EPSG','1198',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7682','GSK-2011',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1159','EPSG','1198',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7683','GSK-2011',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1159','EPSG','1198',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7684','Kyrg-06',NULL,NULL,'geocentric','EPSG','6500','EPSG','1160','EPSG','1137',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7685','Kyrg-06',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1160','EPSG','1137',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7686','Kyrg-06',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1160','EPSG','1137',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7789','ITRF2014',NULL,NULL,'geocentric','EPSG','6500','EPSG','1165','EPSG','2830',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7796','BGS2005',NULL,NULL,'geocentric','EPSG','6500','EPSG','1167','EPSG','1056',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7797','BGS2005',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1167','EPSG','1056',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7798','BGS2005',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1167','EPSG','1056',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7815','WGS 84 (Transit)',NULL,NULL,'geocentric','EPSG','6500','EPSG','1166','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7816','WGS 84 (Transit)',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1166','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7842','GDA2020',NULL,NULL,'geocentric','EPSG','6500','EPSG','1168','EPSG','4177',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7843','GDA2020',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1168','EPSG','4177',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7844','GDA2020',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1168','EPSG','4177',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7879','St. Helena Tritan',NULL,NULL,'geocentric','EPSG','6500','EPSG','1173','EPSG','3183',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7880','St. Helena Tritan',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1173','EPSG','3183',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7881','St. Helena Tritan',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1173','EPSG','3183',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7884','SHGD2015',NULL,NULL,'geocentric','EPSG','6500','EPSG','1174','EPSG','3183',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7885','SHGD2015',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1174','EPSG','3183',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7886','SHGD2015',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1174','EPSG','3183',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7900','ITRF88',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','6647','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7901','ITRF89',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','6648','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7902','ITRF90',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','6649','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7903','ITRF91',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','6650','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7904','ITRF92',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','6651','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7905','ITRF93',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','6652','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7906','ITRF94',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','6653','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7907','ITRF96',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','6654','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7908','ITRF97',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','6655','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7909','ITRF2000',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','6656','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7910','ITRF2005',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','6896','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7911','ITRF2008',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1061','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7912','ITRF2014',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1165','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7914','ETRF89',NULL,NULL,'geocentric','EPSG','6500','EPSG','1178','EPSG','1298',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7915','ETRF89',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1178','EPSG','1298',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7916','ETRF90',NULL,NULL,'geocentric','EPSG','6500','EPSG','1179','EPSG','1298',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7917','ETRF90',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1179','EPSG','1298',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7918','ETRF91',NULL,NULL,'geocentric','EPSG','6500','EPSG','1180','EPSG','1298',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7919','ETRF91',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1180','EPSG','1298',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7920','ETRF92',NULL,NULL,'geocentric','EPSG','6500','EPSG','1181','EPSG','1298',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7921','ETRF92',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1181','EPSG','1298',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7922','ETRF93',NULL,NULL,'geocentric','EPSG','6500','EPSG','1182','EPSG','1298',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7923','ETRF93',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1182','EPSG','1298',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7924','ETRF94',NULL,NULL,'geocentric','EPSG','6500','EPSG','1183','EPSG','1298',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7925','ETRF94',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1183','EPSG','1298',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7926','ETRF96',NULL,NULL,'geocentric','EPSG','6500','EPSG','1184','EPSG','1298',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7927','ETRF96',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1184','EPSG','1298',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7928','ETRF97',NULL,NULL,'geocentric','EPSG','6500','EPSG','1185','EPSG','1298',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7929','ETRF97',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1185','EPSG','1298',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7930','ETRF2000',NULL,NULL,'geocentric','EPSG','6500','EPSG','1186','EPSG','1298',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','7931','ETRF2000',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1186','EPSG','1298',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8042','Gusterberg (Ferro)',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1188','EPSG','4455',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8043','St. Stephen (Ferro)',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1189','EPSG','4456',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8084','ISN2016',NULL,NULL,'geocentric','EPSG','6500','EPSG','1187','EPSG','1120',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8085','ISN2016',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1187','EPSG','1120',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8086','ISN2016',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1187','EPSG','1120',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8227','IGS14',NULL,NULL,'geocentric','EPSG','6500','EPSG','1191','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8230','NAD83(CSRS96)',NULL,NULL,'geocentric','EPSG','6500','EPSG','1192','EPSG','1061',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8231','NAD83(CSRS96)',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1192','EPSG','1061',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8232','NAD83(CSRS96)',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1192','EPSG','1061',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8233','NAD83(CSRS)v2',NULL,NULL,'geocentric','EPSG','6500','EPSG','1193','EPSG','1061',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8235','NAD83(CSRS)v2',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1193','EPSG','1061',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8237','NAD83(CSRS)v2',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1193','EPSG','1061',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8238','NAD83(CSRS)v3',NULL,NULL,'geocentric','EPSG','6500','EPSG','1194','EPSG','1061',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8239','NAD83(CSRS)v3',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1194','EPSG','1061',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8240','NAD83(CSRS)v3',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1194','EPSG','1061',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8242','NAD83(CSRS)v4',NULL,NULL,'geocentric','EPSG','6500','EPSG','1195','EPSG','1061',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8244','NAD83(CSRS)v4',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1195','EPSG','1061',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8246','NAD83(CSRS)v4',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1195','EPSG','1061',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8247','NAD83(CSRS)v5',NULL,NULL,'geocentric','EPSG','6500','EPSG','1196','EPSG','1061',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8248','NAD83(CSRS)v5',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1196','EPSG','1061',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8249','NAD83(CSRS)v5',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1196','EPSG','1061',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8250','NAD83(CSRS)v6',NULL,NULL,'geocentric','EPSG','6500','EPSG','1197','EPSG','1061',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8251','NAD83(CSRS)v6',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1197','EPSG','1061',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8252','NAD83(CSRS)v6',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1197','EPSG','1061',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8253','NAD83(CSRS)v7',NULL,NULL,'geocentric','EPSG','6500','EPSG','1198','EPSG','1061',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8254','NAD83(CSRS)v7',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1198','EPSG','1061',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8255','NAD83(CSRS)v7',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1198','EPSG','1061',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8351','S-JTSK [JTSK03]',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1201','EPSG','1211',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8397','ETRF2005',NULL,NULL,'geocentric','EPSG','6500','EPSG','1204','EPSG','1298',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8399','ETRF2005',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1204','EPSG','1298',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8401','ETRF2014',NULL,NULL,'geocentric','EPSG','6500','EPSG','1206','EPSG','1298',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8403','ETRF2014',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1206','EPSG','1298',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8425','Hong Kong Geodetic CS',NULL,NULL,'geocentric','EPSG','6500','EPSG','1209','EPSG','1118',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8426','Hong Kong Geodetic CS',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1209','EPSG','1118',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8427','Hong Kong Geodetic CS',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1209','EPSG','1118',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8428','Macao 1920',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1207','EPSG','1147',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8429','Macao 2008',NULL,NULL,'geocentric','EPSG','6500','EPSG','1208','EPSG','1147',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8430','Macao 2008',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1208','EPSG','1147',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8431','Macao 2008',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1208','EPSG','1147',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8449','NAD83(FBN)',NULL,NULL,'geographic 2D','EPSG','6423','EPSG','6152','EPSG','4515',NULL,1);
INSERT INTO "geodetic_crs" VALUES('EPSG','8541','NAD83(FBN)',NULL,NULL,'geocentric','EPSG','6500','EPSG','1211','EPSG','4515',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8542','NAD83(FBN)',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1211','EPSG','4515',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8543','NAD83(HARN Corrected)',NULL,NULL,'geocentric','EPSG','6500','EPSG','1212','EPSG','3634',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8544','NAD83(HARN Corrected)',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1212','EPSG','3634',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8545','NAD83(HARN Corrected)',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1212','EPSG','3634',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8683','SRB_ETRS89',NULL,NULL,'geocentric','EPSG','6500','EPSG','1214','EPSG','4543',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8684','SRB_ETRS89',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1214','EPSG','4543',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8685','SRB_ETRS89',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1214','EPSG','4543',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8694','Camacupa 2015',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1217','EPSG','1029',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8697','RSAO13',NULL,NULL,'geocentric','EPSG','6500','EPSG','1220','EPSG','1029',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8698','RSAO13',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1220','EPSG','1029',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8699','RSAO13',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1220','EPSG','1029',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8816','MTRF-2000',NULL,NULL,'geocentric','EPSG','6500','EPSG','1218','EPSG','1206',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8817','MTRF-2000',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1218','EPSG','1206',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8818','MTRF-2000',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1218','EPSG','1206',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8860','NAD83(FBN)',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1211','EPSG','4515',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8888','WGS 84 (Transit)',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1166','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8898','RGWF96',NULL,NULL,'geocentric','EPSG','6500','EPSG','1223','EPSG','1255',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8899','RGWF96',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1223','EPSG','1255',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8900','RGWF96',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1223','EPSG','1255',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8901','RGWF96 (lon-lat)',NULL,NULL,'geographic 3D','EPSG','6426','EPSG','1223','EPSG','1255',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8902','RGWF96 (lon-lat)',NULL,NULL,'geographic 2D','EPSG','6424','EPSG','1223','EPSG','1255',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8905','CR-SIRGAS',NULL,NULL,'geocentric','EPSG','6500','EPSG','1225','EPSG','1074',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8906','CR-SIRGAS',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1225','EPSG','1074',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8907','CR-SIRGAS',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1225','EPSG','1074',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8915','SIRGAS-CON DGF00P01',NULL,NULL,'geocentric','EPSG','6500','EPSG','1227','EPSG','4530',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8916','SIRGAS-CON DGF00P01',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1227','EPSG','4530',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8917','SIRGAS-CON DGF01P01',NULL,NULL,'geocentric','EPSG','6500','EPSG','1228','EPSG','4530',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8918','SIRGAS-CON DGF01P01',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1228','EPSG','4530',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8919','SIRGAS-CON DGF01P02',NULL,NULL,'geocentric','EPSG','6500','EPSG','1229','EPSG','4530',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8920','SIRGAS-CON DGF01P02',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1229','EPSG','4530',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8921','SIRGAS-CON DGF02P01',NULL,NULL,'geocentric','EPSG','6500','EPSG','1230','EPSG','4530',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8922','SIRGAS-CON DGF02P01',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1230','EPSG','4530',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8923','SIRGAS-CON DGF04P01',NULL,NULL,'geocentric','EPSG','6500','EPSG','1231','EPSG','4530',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8924','SIRGAS-CON DGF04P01',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1231','EPSG','4530',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8925','SIRGAS-CON DGF05P01',NULL,NULL,'geocentric','EPSG','6500','EPSG','1232','EPSG','4530',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8926','SIRGAS-CON DGF05P01',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1232','EPSG','4530',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8927','SIRGAS-CON DGF06P01',NULL,NULL,'geocentric','EPSG','6500','EPSG','1233','EPSG','4530',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8928','SIRGAS-CON DGF06P01',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1233','EPSG','4530',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8929','SIRGAS-CON DGF07P01',NULL,NULL,'geocentric','EPSG','6500','EPSG','1234','EPSG','4530',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8930','SIRGAS-CON DGF07P01',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1234','EPSG','4530',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8931','SIRGAS-CON DGF08P01',NULL,NULL,'geocentric','EPSG','6500','EPSG','1235','EPSG','4530',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8932','SIRGAS-CON DGF08P01',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1235','EPSG','4530',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8933','SIRGAS-CON SIR09P01',NULL,NULL,'geocentric','EPSG','6500','EPSG','1236','EPSG','4530',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8934','SIRGAS-CON SIR09P01',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1236','EPSG','4530',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8935','SIRGAS-CON SIR10P01',NULL,NULL,'geocentric','EPSG','6500','EPSG','1237','EPSG','4530',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8936','SIRGAS-CON SIR10P01',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1237','EPSG','4530',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8937','SIRGAS-CON SIR11P01',NULL,NULL,'geocentric','EPSG','6500','EPSG','1238','EPSG','4530',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8938','SIRGAS-CON SIR11P01',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1238','EPSG','4530',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8939','SIRGAS-CON SIR13P01',NULL,NULL,'geocentric','EPSG','6500','EPSG','1239','EPSG','4530',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8940','SIRGAS-CON SIR13P01',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1239','EPSG','4530',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8941','SIRGAS-CON SIR14P01',NULL,NULL,'geocentric','EPSG','6500','EPSG','1240','EPSG','4530',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8942','SIRGAS-CON SIR14P01',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1240','EPSG','4530',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8943','SIRGAS-CON SIR15P01',NULL,NULL,'geocentric','EPSG','6500','EPSG','1241','EPSG','4530',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8944','SIRGAS-CON SIR15P01',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1241','EPSG','4530',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8945','SIRGAS-CON SIR17P01',NULL,NULL,'geocentric','EPSG','6500','EPSG','1242','EPSG','4530',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8946','SIRGAS-CON SIR17P01',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1242','EPSG','4530',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8947','SIRGAS-Chile 2010',NULL,NULL,'geocentric','EPSG','6500','EPSG','1243','EPSG','1066',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8948','SIRGAS-Chile 2010',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1243','EPSG','1066',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8949','SIRGAS-Chile 2010',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1243','EPSG','1066',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8972','SIRGAS-CON DGF00P01',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1227','EPSG','4530',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8973','SIRGAS-CON DGF01P01',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1228','EPSG','4530',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8974','SIRGAS-CON DGF01P02',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1229','EPSG','4530',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8975','SIRGAS-CON DGF02P01',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1230','EPSG','4530',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8976','SIRGAS-CON DGF04P01',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1231','EPSG','4530',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8977','SIRGAS-CON DGF05P01',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1232','EPSG','4530',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8978','SIRGAS-CON DGF06P01',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1233','EPSG','4530',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8979','SIRGAS-CON DGF07P01',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1234','EPSG','4530',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8980','SIRGAS-CON DGF08P01',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1235','EPSG','4530',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8981','SIRGAS-CON SIR09P01',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1236','EPSG','4530',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8982','SIRGAS-CON SIR10P01',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1237','EPSG','4530',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8983','SIRGAS-CON SIR11P01',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1238','EPSG','4530',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8984','SIRGAS-CON SIR13P01',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1239','EPSG','4530',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8985','SIRGAS-CON SIR14P01',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1240','EPSG','4530',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8986','SIRGAS-CON SIR15P01',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1241','EPSG','4530',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8987','SIRGAS-CON SIR17P01',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1242','EPSG','4530',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8988','ITRF88',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6647','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8989','ITRF89',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6648','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8990','ITRF90',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6649','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8991','ITRF91',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6650','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8992','ITRF92',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6651','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8993','ITRF93',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6652','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8994','ITRF94',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6653','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8995','ITRF96',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6654','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8996','ITRF97',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6655','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8997','ITRF2000',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6656','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8998','ITRF2005',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6896','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','8999','ITRF2008',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1061','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','9000','ITRF2014',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1165','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','9001','IGS97',NULL,NULL,'geocentric','EPSG','6500','EPSG','1244','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','9002','IGS97',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1244','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','9003','IGS97',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1244','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','9004','IGS00',NULL,NULL,'geocentric','EPSG','6500','EPSG','1245','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','9005','IGS00',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1245','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','9006','IGS00',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1245','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','9007','IGb00',NULL,NULL,'geocentric','EPSG','6500','EPSG','1246','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','9008','IGb00',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1246','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','9009','IGb00',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1246','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','9010','IGS05',NULL,NULL,'geocentric','EPSG','6500','EPSG','1247','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','9011','IGS05',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1247','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','9012','IGS05',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1247','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','9013','IGS08',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1141','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','9014','IGS08',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1141','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','9015','IGb08',NULL,NULL,'geocentric','EPSG','6500','EPSG','1248','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','9016','IGb08',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1248','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','9017','IGb08',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1248','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','9018','IGS14',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1191','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','9019','IGS14',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1191','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','9053','WGS 84 (G730)',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1152','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','9054','WGS 84 (G873)',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1153','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','9055','WGS 84 (G1150)',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1154','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','9056','WGS 84 (G1674)',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1155','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','9057','WGS 84 (G1762)',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1156','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','9059','ETRF89',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1178','EPSG','1298',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','9060','ETRF90',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1179','EPSG','1298',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','9061','ETRF91',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1180','EPSG','1298',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','9062','ETRF92',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1181','EPSG','1298',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','9063','ETRF93',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1182','EPSG','1298',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','9064','ETRF94',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1183','EPSG','1298',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','9065','ETRF96',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1184','EPSG','1298',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','9066','ETRF97',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1185','EPSG','1298',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','9067','ETRF2000',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1186','EPSG','1298',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','9068','ETRF2005',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1204','EPSG','1298',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','9069','ETRF2014',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1206','EPSG','1298',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','9070','NAD83(MARP00)',NULL,NULL,'geocentric','EPSG','6500','EPSG','1221','EPSG','4167',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','9071','NAD83(MARP00)',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1221','EPSG','4167',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','9072','NAD83(MARP00)',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1221','EPSG','4167',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','9073','NAD83(PACP00)',NULL,NULL,'geocentric','EPSG','6500','EPSG','1249','EPSG','4162',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','9074','NAD83(PACP00)',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1249','EPSG','4162',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','9075','NAD83(PACP00)',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1249','EPSG','4162',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','9138','KOSOVAREF01',NULL,NULL,'geocentric','EPSG','6500','EPSG','1251','EPSG','4542',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','9139','KOSOVAREF01',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1251','EPSG','4542',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','9140','KOSOVAREF01',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1251','EPSG','4542',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','9146','SIRGAS-Chile 2013',NULL,NULL,'geocentric','EPSG','6500','EPSG','1252','EPSG','1066',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','9147','SIRGAS-Chile 2013',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1252','EPSG','1066',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','9148','SIRGAS-Chile 2013',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1252','EPSG','1066',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','9151','SIRGAS-Chile 2016',NULL,NULL,'geocentric','EPSG','6500','EPSG','1253','EPSG','1066',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','9152','SIRGAS-Chile 2016',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1253','EPSG','1066',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','9153','SIRGAS-Chile 2016',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1253','EPSG','1066',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','9182','SIRGAS-Chile',NULL,NULL,'geocentric','EPSG','6500','EPSG','1254','EPSG','1066',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','9183','SIRGAS-Chile',NULL,NULL,'geographic 3D','EPSG','6423','EPSG','1254','EPSG','1066',NULL,0);
INSERT INTO "geodetic_crs" VALUES('EPSG','9184','SIRGAS-Chile',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1254','EPSG','1066',NULL,0);
